@@ -27,7 +27,9 @@
   ergm.MHP.table("c", "Bernoulli", "atmost+bd",  1, "TNT", "dissolutionMLETNT")
 
   ergm.MHP.table("c", "Bernoulli", "atleast+observed",  0, "random", "formationNonObservedMLE")
+  ergm.MHP.table("c", "Bernoulli", "atleast+observed",  1, "TNT", "formationNonObservedMLETNT")
   ergm.MHP.table("c", "Bernoulli", "atmost+observed",  0, "random", "dissolutionNonObservedMLE")
+  ergm.MHP.table("c", "Bernoulli", "atmost+observed",  1, "TNT", "dissolutionNonObservedMLETNT")
 
   ergm.MHP.table("c", "Bernoulli", "atleast+blockdiag",  0, "random", "formationMLEblockdiag")
   ergm.MHP.table("c", "Bernoulli", "atleast+bd+blockdiag",  0, "random", "formationMLEblockdiag")
@@ -39,7 +41,9 @@
   ergm.MHP.table("c", "Bernoulli", "atmost+bd+blockdiag",  1, "TNT", "dissolutionMLEblockdiagTNT")
 
   ergm.MHP.table("c", "Bernoulli", "atleast+blockdiag+observed",  0, "random", "formationNonObservedMLEblockdiag")
+  ergm.MHP.table("c", "Bernoulli", "atleast+blockdiag+observed",  1, "TNT", "formationNonObservedMLEblockdiagTNT")
   ergm.MHP.table("c", "Bernoulli", "atmost+blockdiag+observed",  0, "random", "dissolutionNonObservedMLEblockdiag")
+  ergm.MHP.table("c", "Bernoulli", "atmost+blockdiag+observed",  1, "TNT", "dissolutionNonObservedMLEblockdiagTNT")
 
   ergm.MHP.table("f", "Bernoulli", "",  0, "random", "formation")
   ergm.MHP.table("f", "Bernoulli", "bd",  0, "random", "formation")
