@@ -30,12 +30,12 @@ y0<-standardize.network(simulate(y0~edges, coef=theta, control=control.simulate(
 
 cat("Complete data:\n")
 
-set.seed(432)
+set.seed(123)
 y1<-standardize.network(simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2)))
 
 # Force CMPLE
 set.seed(543)
-fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMPLE")
+fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMPLE", times=c(1,2))
 
 stopifnot(fit$estimate=="CMPLE", fit$formation.fit$estimate=="MPLE", fit$dissolution.fit$estimate=="MPLE")
 stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
@@ -43,7 +43,7 @@ stopifnot(all.equal(diss.mle(y0,y1), coef(fit$dissolution.fit), tolerance=tolera
 
 # Autodetected CMPLE
 set.seed(543)
-fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE")
+fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE", times=c(1,2))
 
 stopifnot(fit$estimate=="CMLE", is.null(fit$formation.fit$sample), is.null(fit$dissolution.fit$sample))
 stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
@@ -51,7 +51,7 @@ stopifnot(all.equal(diss.mle(y0,y1), coef(fit$dissolution.fit), tolerance=tolera
 
 # Force CMLE
 set.seed(543)
-fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(force.main=TRUE))
+fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(force.main=TRUE), times=c(1,2))
 
 stopifnot(fit$estimate=="CMLE", fit$formation.fit$estimate=="MLE", fit$dissolution.fit$estimate=="MLE")
 stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
@@ -61,11 +61,14 @@ cat("Missing data:\n")
 
 y1m<-network.copy(y1)
 set.seed(765)
-y1m[as.edgelist(simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2)))]<-NA
+#y1m[as.edgelist(simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2)))]<-NA
+e <- as.edgelist(y1)[1,]
+y1m[e[1], e[2]] <- NA
+y1m[1,2] <- NA
 
 # Force CMPLE
 set.seed(765)
-fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMPLE")
+fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMPLE", times=c(1,2))
 
 stopifnot(fit$estimate=="CMPLE", fit$formation.fit$estimate=="MPLE", fit$dissolution.fit$estimate=="MPLE")
 stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
@@ -73,15 +76,15 @@ stopifnot(all.equal(diss.mle(y0,y1m), coef(fit$dissolution.fit), tolerance=toler
 
 # Autodetected CMPLE
 set.seed(765)
-fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE")
+fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE", times=c(1,2))
 
 stopifnot(fit$estimate=="CMLE", is.null(fit$formation.fit$sample), is.null(fit$dissolution.fit$sample))
 stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
 stopifnot(all.equal(diss.mle(y0,y1m), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
 
 # Force CMLE
-set.seed(765)
-fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(force.main=TRUE))
+set.seed(123)
+fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(force.main=TRUE), times=c(1,2))
 
 stopifnot(fit$estimate=="CMLE", fit$formation.fit$estimate=="MLE", fit$dissolution.fit$estimate=="MLE")
 stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
